import 'react-app-polyfill/ie11';
import React, { ReactNode, useEffect, useState } from 'react';
import { default as AliReactRenderer } from '@alilc/lowcode-react-renderer';
import { createFetchHandler } from '@alilc/lowcode-datasource-fetch-handler';
import { IPublicTypeProjectSchema } from '@alilc/lowcode-types';
import { IAppSchema } from './types';
import { parseSchema, loadPlugins } from './utils/lowcode';

const ReactRenderer = ({
  page,
  app,
  loading,
}: {
  page: IPublicTypeProjectSchema;
  app: IAppSchema;
  loading: ReactNode;
}) => {
  const [data, setData] = useState({});

  useEffect(() => {
    if (!page || !app) {
      return;
    }
    (async () => {
      try {
        const { assets, plugins } = app;
        if (plugins) {
          const pluginsData = JSON.parse(plugins);
          loadPlugins(pluginsData.data);
        }
        const assetsData = JSON.parse(assets);
        const pageData = await parseSchema(page, assetsData?.packages);
        setData(pageData);
      } catch (e) {
        console.error(e);
      }
    })();
  }, [page, app]);

  const { schema, components, i18n = {}, dataSource = {} } = data as any;

  if (!schema || !components) {
    return <div className="render-loading">{loading || 'loading...'}</div>;
  }

  return (
    <AliReactRenderer
      schema={{
        ...schema,
        dataSource,
      }}
      components={components}
      messages={i18n}
      appHelper={{
        requestHandlersMap: {
          fetch: createFetchHandler(),
        },
      }}
    />
  );
};

export default ReactRenderer;
