export interface IAppSchema {
  appId: string;
  title: string;
  logo?: string;
  domain?: string;
  status?: string;
  remark?: string;
  topBar?: string;
  assets: string;
  plugins: string;
  prodVersion: string;
  tenantId: string;
  loginPage: string;
  devVersion: string;
  baseUrl: string;
  version?: string;
  theme?: any;
  layout?: any;
  menuType: string;
}

export type AppAssets = {
  packages: {
    /**
     * npm 包名
     */
    package: string;
    /**
     * 包唯一标识
     */
    id: string;
    /**
     * 包版本号
     */
    version: string;
    /**
     * 组件渲染态视图打包后的 CDN url 列表，包含 js 和 css
     */
    urls?: string[] | any;
    /**
     * 组件编辑态视图打包后的 CDN url 列表，包含 js 和 css
     */
    editUrls?: string[] | any;
    library: string;
  }[];
  components: {
    exportName: string;
    url: string;
    package: {
      npm: string;
    };
    npm: {
      package: string;
      version: string;
    };
    urls: {
      default: string;
    };
    advancedUrls: {
      default: string[];
    };
  }[];
};

export type AppPlugins = {
  data: AppPlugin[];
};

export type AppPlugin = {
  key?: string | number;
  name: string;
  icon: string;
  url: string;
  description: string;
  enable: boolean;
  type: 'builtIn' | 'customize';
  callback?: string;
};
